#include <rtt/os/main.h>

#include <rtt/Logger.hpp>
#include <rtt/TaskContext.hpp>
#include <rtt/PeriodicActivity.hpp>

using namespace std;
using namespace RTT;

namespace Example
{

    /**
     * Every component inherits from the 'TaskContext' class.  This base
     * class allow a user to add a primitive to the interface and contain
     * an ExecutionEngine which executes application code.
     */
    class Hello
        : public TaskContext
    {
    public:
        /**
         * This example sets the interface up in the Constructor
         * of the component.
         */
        Hello(std::string name)
            : RTT::TaskContext(name)
        {
        }

        Hello(std::string name, TaskState initial_state)
            : RTT::TaskContext(name, initial_state)
        {
        }

        void updateHook()
        {
        	log(Info) << "Update !" <<endlog();
        }
        bool configureHook()
        {
            log(Info) << "Configure hook" << endlog();
            this->updateHook();
        	return true;
        }
        bool startHook()
        {
            log(Info) << "Start hook" << endlog();
            return true;
        }
         void errorHook()
        {
            log(Info) << "Error hook" << endlog();
        }
        void stopHook()
        {
            log(Info) << "Stop hook" << endlog();
        }
        void cleanupHook()
        {
            log(Info) << "Cleanup hook" << endlog();
        }

    };
}

using namespace Example;

int ORO_main(int argc, char** argv)
{
    Logger::In in("main()");

    log().setLogLevel( Logger::Info );

    log(Info) << "**** Creating the 'Hello' component ****" <<endlog();
    // Create the task:
    Hello hello("Hello");

    TaskContext* a_task = new Hello("the_task", RTT::TaskCore::PreOperational);

    a_task->setActivity( new PeriodicActivity( 0, 0.5 ));
    a_task->start();

    log(Info) << "a_task->scripting()->loadStateMachines(ouach.osd)" <<endlog();
    a_task->scripting()->loadStateMachines("ouach.osd");
    
    log(Info) << "a_task->scripting()->loadStateMachines(veryverylongnametocrash.osd)" <<endlog();
    a_task->scripting()->loadStateMachines("veryverylongnametocrash.osd");


    log(Info) << "delete task" <<endlog();
    delete a_task;

    return 0;
}
